<?
/**
* NodoClass:
*
* Clase que implementa la funcionalidad necesaria para el manejo de los nodos.
* Se definen como variables de clase todas las posibles propiedades de los nodos ademas
* de metodos que permiten cargar estas propiedades partiendo de los archivos xml de configuracin.
*
* Por otra parte tambien se proporcionan en esta clase metodos para la representacin en pantalla de los nodos,
* En funcin de las caracteristicas del nodo almacenadas en las variables de clase.
*
* Por ultimo , la clase tambien proporciona mtodos para la actualizacin de los archivos xml de configuracin
* con los valores almacenados en las variables de una instancia del nodo modificado.
* 
* Se ha utilizado XAJAX  en las funciones encargadas de la representacin en pantalla de los nodos y sympleXML para 
* el tratamiento de los archivos XML en cuanto a la lectura y recorrido.

* @package CSLEditor
*
* @author Alberto Gonzalec Cristiano,Ricardo Campos Garcia, Francisco Zanon Ordoez.
*
* @copyright.
*
* @version Beta
*/
require("tree.common.php");
require_once("xajax.inc.php"); 
class NodoClass{
//********************************************************************************************************************
//                                  VARIABLES DE CLASE
//********************************************************************************************************************
    /**
* String que guarda el identificador de la instancia definida en cada momento.
* Este identificador se corresponde con el campo identifier del manifiesto imsmanifest.xml
* Identifica univocamente el nodo dentro de la estructura de la coleccin.
*
* @var int Id 
*/
 var $Id;
/**
* String que representa el nombre de la instancia de la clase nodo este campo tambien se extrae del archivo imsmanifest.xml
* Concretamente se corresponde con el campo title del elemento seleccionado.
*
* @var String Nombre 
*/
 var $Nombre;
     /**
* String que representa la ruta absoluta donde estaran todos los recursos para ese nodo
* En una primera versin Beta este campo no se utiliza pero esta pensado para futuras actualizaciones.
* 
* @var String RutaAbsoluta 
*/
 var $RutaAbsoluta;
     /**
* String que representa la ruta relativa donde estaran todos los recursos para ese nodo
* En una primera versin Beta este campo no se utiliza pero esta pensado para futuras actualizaciones.
*
* @var String Rutarelativa 
*/
 var $RutaRelativa;
     /**
* Variable que guarda El id del usuario que creo el nodo inicialmente.
* Esta informacin se encuentra almacenada en el archivo de configuracin org.xml, que es un 
* archivo xml auxiliar donde guardamos toda la informacin extra del curso que no podemos guardar en el manifest.
* En concreto se corresponde con el atributo name del tag usr.
*
* @var Integer UsuarioCreador 
*/
 var $UsuarioCreador;
/**
* Variable que guarda la fecha y hora de creacin del nodo
*
* Esta informacin se encuentra almacenada en el archivo de configuracin org.xml, que es un 
* archivo xml auxiliar donde guardamos toda la informacin extra del curso que no podemos guardar en el manifest.
* En concreto se corresponde con el atributo date del tag usr.
*
* @var Date/time FechaCreacion 
*/
 var $FechaCreacion;
/**
* Array que guarda los permisos con los que se creo el curso.
* El usuario que lo crea puede dar permisos de Consulta,Edicion....
* En primeras versiones esta variable no se usa pero esta pensada para el uso futuro en nuevas versiones.
*
* @var Array ArrayPermisos 
*/
 var $ArrayPermisos;
/**
* Variable que guarda la fecha y hora de Ultima Modificacion  del nodo
*
* Esta informacin se encuentra almacenada en el archivo de configuracin org.xml, que es un 
* archivo xml auxiliar donde guardamos toda la informacin extra del curso que no podemos guardar en el manifest.
* En concreto se corresponde con el atributo lastupdate del tag usr.

*
* @var Date/time FechaCreacion 
*/
 var $FechaUltModif;
     /**
* array que guarda :
*  Los posibles estados del nodo
*
*  En primeras versiones no se usa.
* @var string ArrayEstados 
*/

 var $ArrayEstados;
/**
* Variable que guarda el estado actual del nodo :
*  Protegido
*  Bloqueado ...
*
* Esta variable se carga del archovo de configuracin org.xml
* en concreto se corresponde a el campo state del elemento en cuestin.
*
* @var string ArrayRecursos 
*/

 var $EstadoActual;



     /**
* String que guarda :
*  Nombre del documento xml que define el tipo de nodo
*
* Este parametro es importante ya que es el que define el tipo y por tanto las caracteristicas del nodo en cuestion.  
*
* @var string tipo 
*/

 var $Tipo;
 
     /**
* array que guarda :
*  Recursos asociados a el nodo.
*
* Esta informacin se encuentra en la parte de resources del archivo imsmanifest
* @var string ArrayRecursos 
*/

 var $ArrayRecursos;
     /**
* array que guarda :
*  Los diferentes tipos de hijos posibles para este nodo

* @var Array ArrayTiposHijo
*/

 var $ArrayTiposHijo;

     /**
* matriz que guarda los posibles iconos segun el estado y si esta expandido o no
*  

* @var Array MatrizIconos
*/

 var $MatrizIconos;

     /**
* matriz que guarda los posibles iconos segun el estado :
*  

* @var String IconoActual
*/

 var $IconoActual;


 /**
* array que guarda :
*  Las diferentes nombres de hijos....
*  
* @var Array  ArrayHijos.
*/
 var $ArrayHijos;
 /**
* String que guarda :
*  El nombre del archivo php que edita este tipo de nodo
*  
*  
* @var String  Editor.
*/
 var $Editor;
 /**
* String que guarda :
*  El identificador del manifest necesario para que las funciones xajax sepan que nodo se ha seleccionado
*  
*  
* @var String  ManifestId.
*/
 var $ManifestId;
 /**
* Entero que guarda :
*  El nivel de profundidad en el que se encuentra el nodo actual.
*  
*  
* @var String  DepthLevel.
*/
 var $DepthLevel;
  /**
* Array que guarda :
*  El identificador de todos los subnodos de uno dado.
*  
*  
* @var String  SubNodesArray.
*/
 var $SubNodesArray;
 
 //*****************************************************************************************************************
 //                                               METODOS DE LA CLASE
 //*****************************************************************************************************************
 /**
* Constructor de la clase.
*
* Inicializa las variables de clase.
*  En primer lugar el id es un numero entero. con cada nodo nuevo aumento en uno un contador y lo uso como id.
*
*
* Establece los valores de las variables de clase de un nodo con los valores que le son pasados.
*/
function NodoClass(){

}
 //*****************************************************************************************************************
 /**
* CompareResourcesArray
*
* Funcin que compara los arrais de recursos
* La funcin devuelve 1 si son diferentes.
* Devuelve 0 si no hay diferencia entre los arrays.
*
*
* Recive un parametro que es la variable de la clase nodo que queremos comparar con el nodo que llama a la funcion
* 
*/
function CompareResourcesArray($oldNode){
 $sw=0;// en un principio supongo que son iguales
//echo  $this->Nombre."  -  ".$oldNode->Nombre;
 if($this->ArrayRecursos!=$oldNode->ArrayRecursos){// si el array de recursos del nodoactualizado es != del nodo viejo
  $sw=1;
 }
 return($sw);
}

 //*****************************************************************************************************************

 //*****************************************************************************************************************
 /**
* CompareNodeName
*
* Funcin que compara el nombre del nodo en cuestion con el de otro nodo que se le pasa como parametro 
* La funcin devuelve 1 si son diferentes.
* Devuelve 0 si no hay diferencia entre los nombres.
*
*
* Recive un parametro que es la variable de la clase nodo que queremos comparar con el nodo que llama a la funcion
* 
*/
function CompareNodeName($oldNode){
 $sw=0;// en un principio supongo que son iguales
 if($this->Nombre!=$oldNode->Nombre){// si el nombre del nodoactualizado es != del nodo viejo
  $sw=1;
 }
 return($sw);
}
 //*****************************************************************************************************************
 /**
* UpdateTemp
*
* Esta funcin guarda de nuevo el contenido de temp.xml en el manifest segun sea ORG o REC 
* Ademas de eliminar el temp una vez guardado.
* 
*
*
* 
* 
*/
function UpdateTemp($op){
 $fptemp = fopen($_SESSION['carpeta']."/temp.xml","r");
	$fpxml = fopen($_SESSION['carpeta']."/imsmanifest.xml","r");
	$fpxmltemp=fopen($_SESSION['carpeta']."/imsmanifesttemp.xml","w");
	// recorro el xml manifest
    $var="";$varTemp="";$sw=0;
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	  
	  //if($buffer!=FALSE){
	     if(($op =="1") ||($op =="ORG")){
		   if (ereg("<organization ", $buffer)) { 
              
			  $sw=1;
           }
		   if (ereg("</organizations>", $buffer)) { 
             $sw=0;
           }
		  
	  //echo $buffer."<br>";
	   }else{
	     if (ereg("<resources>", $buffer)) { 
              $sw=1;
           }
		   if (ereg("</resources>", $buffer)) { 
             $sw=0;
           }
	   }
	   
	   if($sw==1){
		   while (!feof($fptemp)) {
	         // leo linea
	          $buffer2 = fgets($fptemp);
			   
			    //if (ereg('<?xml version="1.0" encoding="iso-8859-1"',$buffer2)){
		        if (ereg("xml",$buffer2)){
				  
				  
			    }else{
				   $varTemp=$varTemp.$buffer2;
				   
				}
			 }
	  }else{
		     $varTemp=$varTemp.$buffer;
	  }
	  //}
	 
	}//while
	//echo $var;
	//echo $varTemp;
	fputs($fpxmltemp,$varTemp);
	fclose($fpxml);
	fclose($fptemp);
	fclose($fpxmltemp);
}
 //*****************************************************************************************************************


 //*****************************************************************************************************************
 /**
* GenTemp
*
* Esta funcin se desarrolla debido a un problema con simplexml.
* Justamente la funcin xpath de simplexml no sirve con un archivo imsmanifest.xml de un scorm bien formado.
* Para solucionar el problema extraigo solo la parte del manifiesto que voy a modificar que puede ser los recursos o la organizacion
*
*
* Recive un parametro con la ruta donde esta el manifest a copiar y una opcin que es 1 ORG o 2 REC
* Segun si lo que queremos obtener es la organizacin o los recursos.
*/
function GenTemp($ManifestId,$op){
    $fptemp = fopen($_SESSION['carpeta']."/temp.xml","w");
	$fpxml = fopen($ManifestId,"r");
	// recorro el xml manifest
    $var="";$sw=0;
	fputs($fptemp,'<?xml version="1.0" encoding="iso-8859-1"?>'."\n");
	
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	  //if($buffer!=FALSE){
	     if(($op =="1") ||($op =="ORG")){
		   if (ereg("<organization ", $buffer)) { 
              
			  $sw=1;
           }
		   if (ereg("</organizations>", $buffer)) { 
             $sw=0;
           }
		  
	  //echo $buffer."<br>";
	   }else{
	     if (ereg("<resources>", $buffer)) { 
              $sw=1;
			  
			  str_replace( "adlcp:scormtype","a",$buffer);
           }
		   if (ereg("</manifest>", $buffer)) { 
             $sw=0;
           }
	   }
	   if($sw==1){
		   $var=$var.$buffer;
	      }
	  //}
	 
	}//while
	//echo $var;
	fputs($fptemp,$var);
	fclose($fpxml);
	fclose($fptemp);
}
 //*****************************************************************************************************************
 /**
* Funcin Save()
*  Esta funcin se encarga de actualizar el nombre,el estado actual y la fecha de ultima modificacin
*  Tanto en el manifest como en org.
*  Se usan funciones que extraen la parte a modificar del manifest y la guardan de nuevo una vez modificada.
*
**/
function Save(){
    // primero el manifest, (luego ya el org)
    $urlMani=$_SESSION['carpeta']."/imsmanifest.xml";
    $urlOrg=$_SESSION['carpeta']."/org.xml";
    $identifier=$this->Id;
    $UrlTemp=$_SESSION['carpeta']."/temp.xml";
  
   $xml=simplexml_load_file($urlMani);
	$op="ORG";// opcin que indica si lo que queremos obtener es la organizacion o los recursos
	$this->GenTemp($urlMani,$op);// getera temp.xml con la porcion de manifest
    $xmlMani=simplexml_load_file($UrlTemp);
   foreach($xmlMani->xpath("//item") as $e){
    
	if((string)$e['identifier']==$identifier){
	   
	   //actualizamos el nombre
	   $e->title=$this->Nombre;
	 //}
	 
	 // actualizo el temporal
	 $xmlMani->asXML($_SESSION['carpeta']."/temp.xml");
	 // funcion que sustituye la parte modificada en el manifest
	 $this->UpdateTemp($op);
	 // una vez actualizado se genera un imsmanifesttemp que ha de sustituir al antiguo
//	 primero eliminamos temp.xml
     unlink($_SESSION['carpeta']."/temp.xml");
	 // eliminamos el viejo manifest
	 unlink($_SESSION['carpeta']."/imsmanifest.xml");
	 // renombramos imsmanifest temp
	rename($_SESSION['carpeta']."/imsmanifesttemp.xml",$_SESSION['carpeta']."/imsmanifest.xml");
	 //echo $sw."<br>".$oldNode->Name."<br>".$this->Name;
	 
	}// si es el elemento seleccionado
   }
   
     //**********************************************
	 //ORG
	 //ahora modificaremos el archivo org.xml
	 // en este caso si se puede hacer con simplexml
	     $xmlOrg=simplexml_load_file($urlOrg);
		 foreach($xmlOrg->xpath('//item') as $elem){
		   if((string)$elem['identifier']==$identifier){
		  
		    // hemos encontrado el nodo buscado
			// comparar lo que se ha modificado y guardar
			
			if($this->Nombre!=(string)$elem->title){
			  $elem->title=$this->Nombre;
			  
			}
			// cambio estado actual
			if($this->EstadoActual!=(string)$elem['state']){
			  $elem['state']=$this->EstadoActual;
			}
			// cambiamos la fecha ultima fecha de actualizacion
			//***********************************
            	$anyo=date("Y");
	            $mes=date("m");
	            $dia=date("d");
             	$fecha = ($dia."-".$mes."-".$anyo);
				$xmlOrg->usr['lastupdate']=$fecha;
	
		   }
		 }
		 $xmlOrg->asXML($_SESSION['carpeta']."/org.xml");
	  
	//*****************************************************************************  
	
	
}

//**********************************************************************
 /**
* Funcin DelNode()
* Funcin que elimina tanto del manifiesto como del archivo de organizacion
* En este caso se ha de modificar el manifest ,eliminando el item y todos sus subitems
* 
* En primer lugar se edita el manifiesto.
* Se va copiando todo en un xml temporal que luego renombraremos como el manifest.
*  Se busca el elemento que se quiere eliminar cuando se encuentra se deja de copiar en el temporal hasta que termina el elemento incluyendo susu subelementos.
*  Ademas se elimina el apartado de recursos del Nodo en cuestion y se recorre el array de hijos del mismo para eliminar tambien todos los recursos de los hijos
* Una vez actualizado el manifest tendremos que actualizar el org eliminando tambien los elementos hijo del seleccionado y el seleccionado
*
**/
function DelNode(){
 
 //*******************************************************************
  // ELIMINAR ELEMENTO AL MANIFEST
  //********************************************************************
	$fpxml = fopen($_SESSION['carpeta']."/imsmanifest.xml","r");
	$fpxmltemp=fopen($_SESSION['carpeta']."/imsmanifesttemp.xml","w");
	// recorro el xml manifest
	
    $var="";$varTemp="";$sw=0;$sw1=0;$swa=0;
	$apertura=0;$cierre=0;
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	
	      
		  
		   if (ereg("<item identifier=\"".$this->Id. "\" ", $buffer)) { 
            $sw=1; 
	
           }
		   
		  
		  if(($sw==1))
		  {
		      if(ereg('<item', $buffer)){
			   $apertura++; 
			   
			  }
			  if(ereg('</item>', $buffer)){
			   $cierre++;
			  
			  }
			
			
		    $buffer="";
		  }
		  	   
		   if(($sw==1)&&($apertura==$cierre)&&($apertura>1)){
		   
		   $buffer="";
					$sw=0;
					$sw1=0;
		  }
		  if(($sw==1)&&($apertura==$cierre)&&($apertura<=1)){
		   $buffer="";
					$sw=0;
					$sw1=0;
		  }
	  
	       
			// para eliminar los recursos del nodo
			 if(ereg("<resource identifier=\"".$this->Id."_IDREF\"",$buffer)){
		      echo "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;Se ha eliminado el nodo y todos sus hijos";
			  $swa=1;
		     }
			
		    if((ereg('</resource>',$buffer))&& ($swa==1)){
		     $swa=0;
		     $buffer="";
		    }
	         if($swa==1){
			  $buffer="";
			 }
			 
			 // para eliminar los hijos del nodo seleccionado
			 if(count($this->ArrayHijos)>0){
			   foreach($this->ArrayHijos as $a=>$b){
			   // recorro el array de hijos
			     if(ereg("<resource identifier=\"".$b."_IDREF\"",$buffer)){
		          
			       $swa=1;
		         }
			
		         if((ereg('</resource>',$buffer))&& ($swa==1)){
		          $swa=0;
		          $buffer="";
		         }
	             if($swa==1){
			       $buffer="";
			     }
			   }//for
			  }//if
		     $varTemp=$varTemp.$buffer;
	  
	 
	 
	}//while
	//echo $var;
	//echo $varTemp;
	fputs($fpxmltemp,$varTemp);
	fclose($fpxml);
	fclose($fpxmltemp);
		 // eliminamos el viejo manifest
		 
	 unlink($_SESSION['carpeta']."/imsmanifest.xml");
	 
	 // renombramos imsmanifest temp
	rename($_SESSION['carpeta']."/imsmanifesttemp.xml",$_SESSION['carpeta']."/imsmanifest.xml");

	
	//***********************************************************************
	// MODIFICACION DEL ORG
	//**********************************************************************
		$fpxml = fopen($_SESSION['carpeta']."/org.xml","r");
	$fpxmltemp=fopen($_SESSION['carpeta']."/orgtemp.xml","w");
	// recorro el xml manifest
	
    $var="";$varTemp="";$sw=0;$sw1=0;$swa=0;
	$apertura=0;$cierre=0;
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	
	     
		  
		   if (ereg(" identifier=\"".$this->Id. "\" ", $buffer)) { 
            $sw=1; 
			
           }
		   
		  
		  if(($sw==1))
		  {
		      if(ereg('<item ', $buffer)){
			   $apertura++; 
			   
			   
			  }
			  if(ereg('</item>', $buffer)){
			   $cierre++;
			 
			  }
			
			
		    $buffer="";
		  }
		  	   
		   if(($sw==1)&&($apertura==$cierre)&&($apertura>1)){
		   
		   $buffer="";
					$sw=0;
					
		  }
		  if(($sw==1)&&($apertura==$cierre)&&($apertura<=1)){
		   $buffer="";
					$sw=0;
					
		  }
	  
	       
			
		     $varTemp=$varTemp.$buffer;
	  
	 
	 
	}//while
	//echo $var;
	//echo $varTemp;
	fputs($fpxmltemp,$varTemp);
	fclose($fpxml);
	fclose($fpxmltemp);
		 // eliminamos el viejo manifest
		 
	 unlink($_SESSION['carpeta']."/org.xml");
	 
	 // renombramos imsmanifest temp
	rename($_SESSION['carpeta']."/orgtemp.xml",$_SESSION['carpeta']."/org.xml");

	
 }
//**********************************************************************
 /**
* Funcin AddChild(Hijo)
* Funcin que guarda el Nodo hijo como hijo del nodo que llama a la funcion
* En este caso se ha de modificar el manifest , aadiendo un item como hijo del item con los datos del pare
* Por otra parte habra que aadir un apartado de resources para este item
* 
* Una vez actualizado el manifest tendremos que actualizar el org
*
* @param Nodo $ChildNode Guarda una variable de tipo nodo con los datos del hijo a aadir
**/
function AddChild($ChildNode){
   
  //*******************************************************************
  // AADIR EL HIJO AL MANIFEST
  //********************************************************************
	$fpxml = fopen($_SESSION['carpeta']."/imsmanifest.xml","r");
	$fpxmltemp=fopen($_SESSION['carpeta']."/imsmanifesttemp.xml","w");
	// recorro el xml manifest
	
    $var="";$varTemp="";$sw=0;$sw1=0;$sw2=0;
	$apertura=1;$cierre=0;
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	
	      
		   if (ereg('<item identifier="'.$this->Id.'" ', $buffer)) { 
            $sw=1;
			$sw2=1;
           }
		   if(($sw==1)&&(ereg('</title>', $buffer)))
		  {
		    $sw1=1;
		  }
		  if($sw1==1){
		      if(ereg('<item ', $buffer)){
			   $apertura++;
			   
			  }
			  if(ereg('</item>', $buffer)){
			   $cierre++;
			  }
			
		  }	   
		   if(($sw1==1)&&($apertura==$cierre)&&($apertura>1)){
		   
		   $buffer='<item identifier="'.$ChildNode->Id.'" identifierref="'.$ChildNode->Id.'_IDREF" isvisible="true">'."\n".'<title>'.$ChildNode->Nombre.'</title>'."\n".'</item>'."\n".$buffer."\n";
					$sw=0;
					$sw1=0;
		  }
		  if(($sw1==1)&&($apertura==$cierre)&&($apertura<=1)){
		   $buffer='<item identifier="'.$ChildNode->Id.'" identifierref="'.$ChildNode->Id.'_IDREF" isvisible="true">'."\n".'<title>'.$ChildNode->Nombre.'</title>'."\n".'</item>'."\n".$buffer."\n";
					$sw=0;
					$sw1=0;
		  }
	  
	     if (ereg('<resources>', $buffer)) { 
         
		   $buffer=$buffer.'<resource identifier="'.$ChildNode->Id.'_IDREF" type="webcontent" href=""  adlcp:scormtype="sco">'."\n".'</resource>'."\n";
					//$sw=0;
		  }
	
		     $varTemp=$varTemp.$buffer;
	  
	  //}
	 
	}//while
	
	
	
	fputs($fpxmltemp,$varTemp);
	fclose($fpxml);
	fclose($fpxmltemp);
	     unlink($_SESSION['carpeta']."/imsmanifest.xml");
	 
	    // renombramos imsmanifest temp
	    rename($_SESSION['carpeta']."/imsmanifesttemp.xml",$_SESSION['carpeta']."/imsmanifest.xml");
		 // SI AUN NO HAY NINGUN ITEM RECORRO DE OTRA FORMA
if($sw2==0){
    $fpxml = fopen($_SESSION['carpeta']."/imsmanifest.xml","r");
	$fpxmltemp=fopen($_SESSION['carpeta']."/imsmanifesttemp.xml","w");
	$var="";$varTemp="";$sw=0;$sw1=0;$sw2=0;$sw7 = 0;
	$apertura=0;$cierre=0;
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	
	      
		 if(ereg('<organization ',$buffer))
		 	$sw7 = 1;  
		   if((ereg('<title>', $buffer)) && $sw7 == 1)
		  {
		    $sw7 = 0;
			$buffer="\n".$buffer.'<item identifier="'.$ChildNode->Id.'" identifierref="'.$ChildNode->Id.'_IDREF" isvisible="true">'."\n".'<title>'.$ChildNode->Nombre.'</title>'."\n".'</item>'."\n";
					
		 }
	     
		     $varTemp=$varTemp.$buffer;
	 
	}//while
	
	
	
	fputs($fpxmltemp,$varTemp);
	fclose($fpxml);
	fclose($fpxmltemp);
	     unlink($_SESSION['carpeta']."/imsmanifest.xml");
	 
	 // renombramos imsmanifest temp
	rename($_SESSION['carpeta']."/imsmanifesttemp.xml",$_SESSION['carpeta']."/imsmanifest.xml");
}
		 
	

	
	//***********************************************************************
	// MODIFICACION DEL ORG
	//**********************************************************************
		$fpxml = fopen($_SESSION['carpeta']."/org.xml","r");
	$fpxmltemp=fopen($_SESSION['carpeta']."/orgtemp.xml","w");
	// recorro el xml manifest
	
    $var="";$varTemp="";$sw=0;$sw1=0;
	$apertura=1;$cierre=0;
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	
	      
		   if (ereg(' identifier="'.$this->Id.'" ', $buffer)) { 
            $sw=1;
			  
           }
		   if(($sw==1)&&(ereg('</title>', $buffer)))
		  {
		    $sw1=1;
		  }
		  if($sw1==1){
		      if(ereg('<item type', $buffer)){
			
			   $apertura ++;
			  }
			  if(ereg('</item>', $buffer)){
			 
			   $cierre++;
			  }
			
		  }	   
		   if(($sw1==1)&&($apertura==$cierre)&&($apertura>1)){
		   
		   $buffer='          <item type="'.$ChildNode->Tipo.'" state="'.$ChildNode->EstadoActual.'" open="false" identifier="'.$ChildNode->Id.'" identifierref="'.$ChildNode->Id.'_IDREF" depth="'.(string)(((int)$this->DepthLevel)+1).'">
						                   <title>'.$ChildNode->Nombre.'</title>
					             </item>'."\n".$buffer;
					$sw=0;
					$sw1=0;
		  }
		  if(($sw1==1)&&($apertura==$cierre)&&($apertura<=1)){
   $buffer='          <item type="'.$ChildNode->Tipo.'" state="'.$ChildNode->EstadoActual.'" open="false" identifier="'.$ChildNode->Id.'" identifierref="'.$ChildNode->Id.'_IDREF" depth="'.(string)(((int)$this->DepthLevel)+1).'">
						                   <title>'.$ChildNode->Nombre.'</title>
					             </item>'."\n".$buffer;	
					$sw=0;
					$sw1=0;
		  }
	  
	     
	
		     $varTemp=$varTemp.$buffer;
	  
	  //}
	 
	}//while
	//echo $var;
	//echo $varTemp;
	fputs($fpxmltemp,$varTemp);
	fclose($fpxml);
	fclose($fpxmltemp);
		 // eliminamos el viejo manifest
		 
	 unlink($_SESSION['carpeta']."/org.xml");
	 
	 // renombramos imsmanifest temp
	rename($_SESSION['carpeta']."/orgtemp.xml",$_SESSION['carpeta']."/org.xml");
	
	
}
 //*****************************************************************************************************************
 /**
* Funcin que guarda el array de recursoso para un nodo
* en este caso no hace falta usar el ext por que los recursos estan todos como una lista dentro de resources , solo sacando sus hijos
ya recorremos toda la lista de recursos.
con los hijos de estos , los files.
**/
function SaveResources(){
    // primero el manifest, (luego ya el org)
    $urlMani=$_SESSION['carpeta']."/imsmanifest.xml";
    $identifier=$this->Id;
    $UrlTemp=$_SESSION['carpeta']."/temp.xml";
  
   $xml=simplexml_load_file($urlMani);
	$op="ORG";// opcin que indica si lo que queremos obtener es la organizacion o los recursos
	$this->GenTemp($urlMani,$op);// getera temp.xml con la porcion de manifest
    $xmlMani=simplexml_load_file($UrlTemp);
   foreach($xmlMani->xpath("//item") as $e){
    
	if((string)$e['identifier']==$identifier){
	 // me guardo el identifierref
	 $identifierref=(string)$e['identifierref'];
	 // en este caso hemos encontrado el elemento buscado
	 // creamos una variable original con los datos antes de modificar.
	 // los datos modificados ya estan en la instancia  de clase nodo que se esta usando
	 // en el caso del manifest y obteniendo ORG
	 // solo podemos 
	 $oldNode= new NodoClass();
	 $oldNode->extraeNodoPorManiId($identifier);
	 //array
	 $sw=$this->CompareResourcesArray($oldNode);
	  // si el nombre es distinto
	 if($sw==1){
	   //actualizamos el array
	   $oldNode->ArrayRecursos=$this->ArrayRecursos;
	 }
	 // elimino los recursos para ese elemento
	  
	$fpxml = fopen($_SESSION['carpeta']."/imsmanifest.xml","r");
	$fpxmltemp=fopen($_SESSION['carpeta']."/imsmanifesttemp.xml","w");
	// recorro el xml manifest
    $var="";$varTemp="";$sw=1;$swp0=0;
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	  
	  
	    
	     if (ereg("<resource identifier=\"".$identifierref."\"", $buffer)) { 
          fputs($fpxmltemp,$buffer);          
			  $sw=0;
			  
           }
		   if (ereg("</resource>", $buffer)) { 
             $sw=1;
           }
	       
	   
	   if(($sw==1)){
		   
			fputs($fpxmltemp,$buffer);
//		     $varTemp=$varTemp.$buffer;
			 
	  }
	  //}
	 
	}//while
	//echo $var;
	//echo $varTemp;
	
	fclose($fpxml);
	fclose($fpxmltemp);
		// eliminamos el viejo manifest
	 unlink($_SESSION['carpeta']."/imsmanifest.xml");
	 // renombramos imsmanifest temp
	 rename($_SESSION['carpeta']."/imsmanifesttemp.xml",$_SESSION['carpeta']."/imsmanifest.xml");
	 //******************************************************************************************
	// METO LOS NUEVOS RECURSOS*****************************************************************
	$fpxml = fopen($_SESSION['carpeta']."/imsmanifest.xml","r");
	$fpxmltemp=fopen($_SESSION['carpeta']."/imsmanifesttemp.xml","w");
	// recorro el xml manifest
    $var="";$varTemp="";$sw=1;$swp0=0;
	while (!feof($fpxml)) {
	  // leo linea
	  $buffer = fgets($fpxml);
	  
	  //if($buffer!=FALSE){
	    
	     if (ereg('<resource identifier="'.$identifierref.'"', $buffer)) { 
          fputs($fpxmltemp,$buffer);          
			  foreach($oldNode->ArrayRecursos as $a=>$files){
			    fputs($fpxmltemp,'            <file href="'.$files.'"/>'."\n");
			  }
			  $sw=0;
			  
           }
		   if (ereg("</resource>", $buffer)) { 
             $sw=1;
           }
	       
	   
	   if(($sw==1)){
		   
			fputs($fpxmltemp,$buffer);
//		     $varTemp=$varTemp.$buffer;
			 
	  }
	  //}
	 
	}//while
	//echo $var;
	//echo $varTemp;
	
	fclose($fpxml);
	fclose($fpxmltemp);
	 //**************************************************
	
		//************************************************+
		// eliminamos el viejo manifest
	 unlink($_SESSION['carpeta']."/imsmanifest.xml");
	 // renombramos imsmanifest temp
	 rename($_SESSION['carpeta']."/imsmanifesttemp.xml",$_SESSION['carpeta']."/imsmanifest.xml");
	
	}// si es el elemento seleccionado
   }
}
 //*****************************************************************************************************************
 /**
* Funcin que extrae y carga en las variables de clase nodo todos los datos de un nodo dado por su nombre. 
*
* @param String $nombre Guarda nombre del nodo a buscar
*/

// carga en la variable de clase en cuestion todos los datosseleccionados por el nombre
function extraeNodoPorNom($nombre){
$objResponse = new xajaxResponse();
  $url=$_SESSION['carpeta']."/"."org.xml";
  //$objResponse->addAlert("Entraextraer por nom!!!!!!!!!! ".$nombre." - ".$_SESSION['carpeta']);
   if (file_exists($url))
{
   //echo $url;
   $ObjOrg = simplexml_load_file($url);
  foreach($ObjOrg->xpath('//item') as $elemento){

//    saco  el tipo del nodo raiz para generar el nodo 
	if($nombre==(string)$elemento->title){
  	 // $objResponse->addAlert("Hemos encontrado el buscado");
	   $TipoNodo=(string)$elemento['type'];
	//$objResponse->addAlert("tipoNodo :".$TipoNodo);
       $estructura =$_SESSION['carpeta'].'/struct.xml';
       $config=$_SESSION['carpeta']."/".$TipoNodo.'.xml';
  	   $IdManifest=(string)$elemento['identifier'];

	   $this->Genera(0,(string)$elemento->title,$TipoNodo,$estructura,$config,$IdManifest,$_SESSION['carpeta']);
	   $a=(string)$elemento['state'];$b=(string)$elemento['open'];
	   $this->EstadoActual=$a;
	   //echo $a;echo $b;echo $raiz->MatrizIconos["$a"]["$b"];
	   $this->IconoActual=$this->MatrizIconos["$a"]["$b"];
	}
  }
 }
return $objResponse;
}
/////////////////////////////////
// carga en la variable de clase en cuestion todos los datosseleccionados por el nombre
function extraeNodoPorManiId($ManiId){
$objResponse = new xajaxResponse();
  $url=$_SESSION['carpeta']."/"."org.xml";
  //$objResponse->addAlert("Entraextraer por Mani ID!!!!!!!!!! ".$ManiId." - ".$_SESSION['carpeta']);
   if (file_exists($url))
{
   //echo $url;
   $ObjOrg = simplexml_load_file($url);
  foreach($ObjOrg->xpath('//item') as $elemento){
 // $objResponse->addAlert("Recorriendo elem");
//    saco  el tipo del nodo raiz para generar el nodo 
	if($ManiId==(string)$elemento['identifier']){
  	 // $objResponse->addAlert("Hemos encontrado el buscado");
	   $nombreNodo=(string)$elemento->title;
	   $TipoNodo=(string)$elemento['type'];
	   //$objResponse->addAlert("tipoNodo :".$TipoNodo);
       $estructura =$_SESSION['carpeta'].'/struct.xml';
       $config=$_SESSION['carpeta']."/".$TipoNodo.'.xml';
  	   $IdManifest=(string)$elemento['identifier'];

	   $this->Genera($IdManifest,$nombreNodo,$TipoNodo,$estructura,$config,$IdManifest,$_SESSION['carpeta']);
	   
	   $a=(string)$elemento['state'];$b=(string)$elemento['open'];
	   $this->EstadoActual=$a;
	   //echo $a;echo $b;echo $raiz->MatrizIconos["$a"]["$b"];
	   $this->IconoActual=$this->MatrizIconos["$a"]["$b"];
	   $this->CargaTiposHijo($estructura,$debug);
	}
  }
 }
return $objResponse;
}
/////////////////////////////////
  /**
* LoadDepth.
*
*  Esta funcion Almacena el nivel de profundidad  correspondiente a cada nodo en la variable de la clase nodo DepthLevel.
*  Recorre Ee archovo de organizacin utilizando un contador.
*
*  .
*   
*
* 
*/
function LoadDepth(){

//necesito hacer esto nivel, o guardarlo en el org, mejos de momento al org
$url=$_SESSION['carpeta']."/"."org.xml";
     if (file_exists($url))
     {
     //echo $url;
       $ObjOrg = simplexml_load_file($url);
        foreach ($ObjOrg->xpath('//item') as $elemento) {
	      
           if((string)$elemento['identifier']==$this->Id){
		    $this->DepthLevel=(int)$elemento['depth'];
		   }
		}
	  }
	 
}
//////////////////////////////////////////////////////////////////////////
/**
* Funcion Genera.
* Esta funcin inicializa una instancia de la clase nodo y carga los valores necesarios de los archivos
* de configuracin XML
*
* @param String $id Guarda el id del nodo a generar
* @param String $nombre Guarda el nombre del nodo a generar. 
* @param String $tipo Guarda el tipo del nodo a generar
* @param String $Estructura Guarda la url del archivo de estructura
* @param String $Config Guarda la url del archivo de configuracion
* @param String $carpeta Guarda la carpeta del curso o coleccion
*
**/
 function Genera($id,$nombre,$tipo,$Estructura,$Config,$ManId,$carpeta){
  $this->Id=$id;
  $this->Nombre=$nombre;
  $this->RutaAbsoluta="";$this->RutaRelativa="";
  $this->UsuarioCreadorid="";$this->UsuarioCreadorNom="";$this->FechaCreacion="";
  $this->ArrayPermisos=NULL;$this->FechaUltModif="";
  $this->ArrayEstados=NULL;$this->EstadoActual="";
  $this->ArrayRecursos=NULL;$this->MatrizIconos=NULL;
  $this->IconoActual="";
 $this->ArrayTipoHijos=NULL;$this->SubNodesArray=NULL;
  $this->Tipo=$tipo;
  $this->ArrayHijos=NULL;
  $this->Editor="";
  $this->ManifestId=$id;
  $this->DepthLevel=0;
  // Cargo los tipos de hijos para este nodo del archivo struct
 $this->CargaTiposHijo($Estructura,$debug);
  // cargo el archivo de configuracion
  $this->CargaConfig($Config,$debug);
  $this->CargaUsuarioEdicion($carpeta);
  $this->CargaRecursos($carpeta);
  $this->CargaHijos($carpeta);
  // guardo el nivel de profundidad del elemento en el arbol.
  $this->LoadDepth();
  // dargar array de subnodos para que cuando contraiga eliminar todos los subnodos que existan
  $this->LoadSubNodes();
 }
  //***********************************************************************************
  /**
* CargarUsuarioEdicion.
* Carga los datos del usuario tanto que lo creo como el ultimo en editar
* asi como las fechas de creacin y de ultima modificacion.
* @param String $carpeta Guarda el nombre de la carpeta donde estan guardados todos los archivos relacionados 
* con la coleccion en cuestion. 
*/
 function CargaUsuarioEdicion($carpeta){
    
	$urlorg=$carpeta."/org.xml";
	//echo $urlMani;echo $urlog;
	//echo $urlorg;
	 if ((file_exists($urlorg)))
	 {
  	  // saco el identifierref de org
	  $ObjXmlOrg1 = simplexml_load_file($urlorg);
	  $this->UsuarioCreadorid=(string)$ObjXmlOrg1->usr['id'];
	  $this->UsuarioCreadorNom=(string)$ObjXmlOrg1->usr['name'];
	  $this->FechaCreacion=(string)$ObjXmlOrg1->usr['date'];
	  $this->FechaUltModif=(string)$ObjXmlOrg1->usr['lastupdate'];
	 // echo (string)$ObjXmlOrg1->usr['id'];echo"WWWWWWWWWWWWWW"; echo $this->UsuarioCreadorNom;
	
	 
	 
   	 	}else{
	// controlar error
	}
 }// fin funcion
  //***********************************************************************************
  /**
* CargarHijos()
* Carga el array de hijos a partir de el archivo de configuracion org.xml
*
* @param String $carpeta Guarda el nombre de la carpeta donde estan guardados todos los archivos relacionados 
* con la coleccion en cuestion. 
*/
 function CargaHijos($carpeta){
    
	$urlorg=$carpeta."/org.xml";
	//echo $urlMani;echo $urlog;
	//echo $urlorg;
	 if ((file_exists($urlorg)))
	 {
  	  // saco el identifierref de org
	  $ObjXmlOrg1 = simplexml_load_file($urlorg);
	   foreach($ObjXmlOrg1->xpath('//item') as $elem){
	     if((string)$elem['identifier']==$this->ManifestId){
		   //echo (string)$elem->title;
		   foreach($elem->children() as $hijos){
		     if((string)$hijos->getName()!="title"){
			    //echo (string)$hijos->title;
				$this->AddHijo((string)$hijos['identifier']);
			 }
		   }
		 }
	   }
	 
	 // echo (string)$ObjXmlOrg1->usr['id'];echo"WWWWWWWWWWWWWW"; echo $this->UsuarioCreadorNom;
	
	 
	 
   	 	}else{
	// controlar error
	}
 }// fin funcion

 //***********************************************************************************
   //***********************************************************************************
  /**
* 
* Esta funcin recorre todos los nodos que estan por debajo en la jerarquia y almacena sus id's 
* en el array de sub nodos.
*
*/
function LoadSubNodes(){

	$urlorg=$_SESSION['carpeta']."/org.xml";
	 
	//******************************************
	 if ((file_exists($urlorg)))
	 {
  	  // saco el identifierref de org
	  $ObjXmlOrg1 = simplexml_load_file($urlorg);
	   foreach($ObjXmlOrg1->xpath('//item') as $elem){
	     if((string)$elem['identifier']==$this->ManifestId){
		   //echo (string)$elem->title;
		   $sw=1;
		   $aux=(int)$elem['depth'];//echo "aux: ";echo $aux;echo "</br>";
		 
		 }
		   if(($sw==1)&&((string)$elem['identifier']!=$this->ManifestId)&&((int)$elem['depth'] >$aux)){
			    //echo (string)$hijos->title;
				$this->AddSubNode((string)$elem['identifier']);
			 }
		   if(($sw==1)&&((int)$elem['depth']==$aux)&&((string)$elem['identifier']!=$this->ManifestId)){break;}
		 
		 
	   }
	 
	 // echo (string)$ObjXmlOrg1->usr['id'];echo"WWWWWWWWWWWWWW"; echo $this->UsuarioCreadorNom;
	
	 
	 
   	 	}else{
	// controlar error
	}
	
 }// fin funcion

 //***********************************************************************************
  /**
* CargarRecursos.
* Recorre los elementos de org hasta encontrar el elemento con el nombre del que buscamos sus recursos
* Una vez encontrado voy a ir a buscar su identifierref en el manifest y a sacar los recursos de el 
* con el identifierref.
* Por ultomo rellenar el array de recursos del nodo que se esta cargando
*
* @param String $Carpeta Guarda el nombre de la carpeta donde se alojan los archivos relacionados con la coleccin. 
*/
 function CargaRecursos($carpeta){
    $urlMani=$carpeta."/imsmanifest.xml";
	$urlorg=$carpeta."/org.xml";
	//echo $urlMani;echo $urlog;
	$cont=0;
	 if ((file_exists($urlorg))&&(file_exists($urlMani)))
	 {
  	  // saco el identifierref de org
	  $ObjXmlOrg1 = simplexml_load_file($urlorg);
	   foreach($ObjXmlOrg1->xpath('//item') as $iteme){
	  

	     if((string)$iteme['identifier']==$this->ManifestId){
	       //echo (string)$iteme->title;echo $this->Nombre;
	       $identifierref=(string)$iteme['identifierref'];
		   //echo "+++++++++++++++++++";echo $identifierref;
	     }
	 }
	 
	 
   	 $ObjXmlMani = simplexml_load_file($urlMani);
   	 // recorro manifest:
  	  foreach ($ObjXmlMani->resources->children() as $elemento)
   	   {

			if($elemento['identifier']==$identifierref){
			
			    foreach($elemento->children() as $files){
		       
				    // echo (string)$files['href'];
					 $this->AddRecurso((string)$files['href']);
		  	    }
		    }
		}
    
	}else{
	// controlar error
	}
 }// fin funcion

 //***********************************************************************************
  /**
* CargarTiposHijos.
*
*  Esta funcion Recive el nombre de un fichero xml que define la jerarquia
*  Recorre todos los elementos del archivo de configuracion de la jerarquia y compara el nombre del tipo del nodo 
*  con el elemento, si coinciden estare en el elemento deseado.
*   En ese momento recorro los hijos de ese elemento y almaceno en la lista de posibles tipos de hijo
*
* @param String $url Guarda la url del archivo struct.xml. 

*/
 function CargaTiposHijo($url,$debug){
  // Esta funcion que se ejecutara para cada nodo que se cree abre el archivo de configuracion que contiene la estructura .
  // y busca los posibles tipos de hijos que puede tener el nodo dependiendo del tipo del nodo. 
   
	//echo $url;	
	//defino array para guardar los posibles tipos inicialmente vacio
 
	 if (file_exists($url))
	 {
  	// echo "si existe";
   	 $ObjXmlStruct = simplexml_load_file($url);
   	
   	 // recorro structura:
   
  	  foreach ($ObjXmlStruct->children() as $elemento)
   	   {
//		    busco el atributo nombre en cada hijo como solo tiene 1 atributo que es name solo 1 iteracion
			foreach($elemento->attributes() as $a=>$valor){
		        // si el valor de la propiedad  name coincide con el del tipo de el nodo actual
				 
				if(($a=="name")&&((string)$valor==$this->Tipo)){
		   	       // recorro sus posibles tipos de hijo y los guardo en el array
		   	        foreach($elemento->children() as $TiposHijo){
		   	         // guardo en el array de tipos de hijos
					 $this->ArrayTiposHijo["$TiposHijo"]=(string)$TiposHijo;
					
					
		  	        }
			    }
		  	 }
		  	
		}
    
	}else{
	// controlar error
	}
 // del debug 
 
 
 }// fin funcion
 //***********************************************************************************
 //***********************************************************************************
  /**
* CargarConfig.
*
*  Esta funcion Recive el nombre de un fichero xml que define el nodo en cuestion
*  Recorre todos los elementos del archivo de configuracion  para cargar :
*  - La matriz de posibles iconos para el nodo cuyas filas son el estado del nodo y columnas si esta expandido o no.
*  - El array de posibles estados.
*  Estos datos residen en un archivo de configuracin del tipo de nodo que tendra el mismo nombre que el tipo con el que se corresponde el nodo
*  
*
* @param String $url Guarda la url del archivo tiponodo.xml. 
*/
 function CargaConfig($url){
  
  // Esta funcion que se ejecutara para cada nodo que se cree abre el archivo de definicion  .
  // y busca los datos de posibles iconos,los posibles estados y el php que lo edita. 
   
	//echo $url;	
	//defino array para guardar los posibles tipos inicialmente vacio
 
	if (file_exists($url))
	{
  	  // echo "si existe";
   	  $ObjXmlStruct = simplexml_load_file($url);
   	
   	// recorro structura:
       // relleno array de estados y el de imagenes
  	   foreach($ObjXmlStruct->xpath('//icon') as $elemento){
   	               
		// como hay dos elementos por cada posible estado solo almacenare uno de cada( pej:solo los false)			
					if($elemento['open']=="false"){
					  $this->AddEstado((string)$elemento['state']);
					}
	   }
	  
	  
	   // relleno array de imagenes
  	    foreach ($ObjXmlStruct->xpath('//icon') as $elemento)
   	    {            
					// para cada icono miro si su propiedad open =true entonces sera columna true si no columna false
					// la fila sera el estado(matriz asociativa donde filas estado , columnas open)
					$IndexFila= (string)$elemento['state'];
					$IndexCol=(string)$elemento['open'];					
					$this->MatrizIconos["$IndexFila"]["$IndexCol"]=(string)$elemento['resource'];
					
	    }	  	
		
	   $this->Editor=(string)$ObjXmlStruct->editor;
	 }//else{
	// controlar error
	//}
 
 
 }// fin funcion
 //***********************************************************************************

 /**
* Aadir Permiso.
*
*  Aade un Permiso al array de Permiso .
*  El Permiso  es un string que  se le pasa como parametro.
*  Esta funcin se ha creado pensando en proximas versiones ya que en la bersin beta no hay soporte para los permisos
*   
* @param String $Permiso Guarda el Permiso a aadir. 
* 
*/
 function AddPermiso($Permiso){
  
  $this->ArrayPermisos["$Permiso"]=$Permiso;
  
   
 }
  //***********************************************************************************
 /**
* Eliminar permiso.
*
*  Elimina un permiso del array de permisos del nodo.
*  Esta funcin se ha creado pensando en proximas versiones ya que en la bersin beta no hay soporte para los permisos
*   
* @param String $Permiso Guarda el permiso a eliminar. 
*/
 function DelPermiso($Permiso){
  
	array_splice($this->ArraPermisos,$Permiso,1); 

   
 }
 //***********************************************************************************
 /**
* Aadir Estado.
*
*  Aade un Estado al array de estados .
*  El estado  es un string que  se le pasa como parametro.
*   
* @param String $Estado guarda el posible estado para el nodo a aadir en el array de estados. 
*/
 function AddEstado($Estado){
  
  $this->ArrayEstados["$Estado"]=$Estado;
  
   
 }
  //***********************************************************************************
 /**
* Eliminar Estado.
*
*  Elimina un Estado del array de estados del nodo.
*  
* @param String $Estado Guarda el posible estado del nodo para aadir al array de posibles estados del nodo. 
*   
*/
 function DelEstado($Estado){
  
	array_splice($this->ArraEstados,$Estado,1); 

   
 }
 //***********************************************************************************
 /**
* Aadir recurso.
*
*  Aade un recurso al array de recursos nodo.
*  El recurso  es un string que  se le pasa como parametro.
*  @param String $recurso Guarda el id del recurso a aadir. 
*/
 function AddRecurso($recurso){
  
  $this->ArrayRecursos["$recurso"]=$recurso;// guardo el nodo en el array de hijos
  //$NumAct++;
  //echo $NumAct;
   
 }
 //***********************************************************************************
 /**
* Eliminar Recurso.
*
*  Elimina el recurso con id $Recurso del array de recursos del nodo que llama a la funcin.
*  
* @param String $Recurso Guarda el id del recurso a eliminar del array de recursos. 
*   
*/
 function DelRecurso($Recurso){
  
	array_splice($this->ArrayHijos,$Recurso,1); 

   
 }
  //***********************************************************************************
 /**
* Aadir a array de subnodos.
*
*  Aade un subnodo al array de subnodos que es un array que guarda todos los nodos que estan por debajo
*  del nodo que llama a la funcin sean hijos suyos o no.
*  
* @param String que guarda el id del subnodo. 
*   
*/
 function AddSubNode($hijo){
  
 
  $this->SubNodesArray["$hijo"]=(string)$hijo;// guardo el nodo en el array de hijos
 
  //echo $NumAct;
   
 } 
 //***********************************************************************************
 /**
* Aadir hijo.
*
*  Aade un hijo al nodo.
*  Aade el hijo con id $hijo al array de hijos del nodo que llama a la funcin.
*  
* @param String que guarda el id del nodo hijo. 
*/
 function AddHijo($hijo){
  
 
  $this->ArrayHijos["$hijo"]=$hijo;// guardo el nodo en el array de hijos
 
  //echo $NumAct;
   
 } 
 //***********************************************************************************
 /**
* Eliminar hijo.
*
*  Elimina un hijo del nodo.
*  Elimina el hijo con id $Hijo del array de hijos del nodo que llama a la funcin.
* @param String que guarda el id del nodo hijo.
*   
*/
 function DelHijo($Hijo){
	array_splice($this->ArrayHijos,$Hijo,1); 

 }

   //***********************************************************************************
 /**
* Expandir un nodo.
*  Esta funcin se encarga de expandir o contraer un nodo segun la situacin actual del mismo.
*  En funcin de el parametro expan que recive utiliza unas funciones xajax u otras para generar o
*  eliminar la representacin del nodo.

* @return string $objResponse->getXML() devuelve el xml generado por el objeto response de xajax
* @param string $carpeta Carpeta de el curso o la coleccin
* @param string $expan variable que guarda el estado expandido="mas", contraido="nemos" del nodo
*
*   
*/
 function ExpandirNodo($carpeta,$expan){
   $objResponse = new xajaxResponse();
  //$objResponse->addAlert("Entra expandir!!!!!!!!!! ".$this->ManifestId." - ".$this->Nombre."- ".$carpeta);
   //$objResponse->addAlert("Icono actual ".$this->IconoActual);
   //$objResponse->addAlert("Estado actual ".$this->EstadoActual);
      //$objResponse->addAlert("EXPAN ".$expan);
  if($expan=="mas"){
    // primero de todo vamos a recorrer los hijos del nodo sobre el cual se ha pulsado
     $url=$carpeta."/"."org.xml";
     if (file_exists($url))
     {
     //echo $url;
       $ObjOrg = simplexml_load_file($url);
        foreach ($ObjOrg->xpath('//item') as $elemento) {
	  
        if((string)$elemento['identifier']==$this->ManifestId){
		
		 $ulthijogen=NULL;// contador que uso para saber cual ha sido el ultimo hijo generado, 
          foreach($elemento->children() as $hijos){ 
     		  if((string)$hijos->getName()!="title"){
			    $h=new NodoClass();
			    $TipoNodo=$hijos['type'];
				//$objResponse->addAlert("TIPO >>>>>>>> --------------------------"." - ".$TipoNodo);
			    $estructura =$carpeta.'/struct.xml';
                $config=$carpeta."/".$TipoNodo.'.xml';
			    $ManId=(string)$hijos['identifier'];
			    $h->Genera($ManId,$hijos->title,$TipoNodo,$estructura,$config,$ManId,$carpeta);
				//$objResponse->addAlert("DepthLevel >>>>>>>> --------------------------"." - ".$h->DepthLevel);
			    $a=(string)$hijos['state'];$b=(string)$hijos['open'];
	            $h->EstadoActual=$a;
	             //echo $a;echo $b;echo $raiz->MatrizIconos["$a"]["$b"];
	            $h->IconoActual=$h->MatrizIconos["$a"]["$b"];
				//$objResponse->addAlert("ICONO BUSCADO>>>>>>>> --------------------------"." - ".$h->IconoActual);
                 // esto es para que no los muestre en orden inverso, por que si aado siempretras id de padre 
				 // salen ordenados por orden inverso
				 if($ulthijogen==NULL){
			     $objResponse->addInsertAfter($this->ManifestId,"div",$h->ManifestId);
				 
				 }else{
				  $objResponse->addInsertAfter($ulthijogen,"div",$h->ManifestId);
				 }
				 $ulthijogen=$h->ManifestId;
			     //$objResponse->addAlert("num HIJOS --------------------------"." - ".count($h->ArrayHijos));
				 // antes de representar el nodo calculo el numero de espacios a introducir para una correcta indentacion del arbol
				 // este numero de espacios va en funcion del nivel de profundidad en el arbol de el nodo en cuestion
				 
				 if($h->DepthLevel>2){$spaces="&nbsp;";}else{$spaces="";};
		
				 for($i=0;$i<$h->DepthLevel;$i++){
				  $spaces=$spaces."&nbsp;";
				 }
				 
				 if(count($h->ArrayHijos)>0){
                  //$objResponse->addAlert("TIENE HIJOS --------------------------"." - ".$this->ManifestId.$this->Nombre."- ".$carpeta);
				   //$objResponse->addAlert("ICONO BUSCADO>>>>>>>> --------------------------"." - ".$h->IconoActual);
	              $var=$h->ManifestId;   //-----------------------<span id=".$h->ManifestId."-editar onClick=\"xajax_editar(this.id);return false;\">&nbsp;<img src=\"".$carpeta."/images/editar.gif\" width=\"17\" height=\"16\"></span><span id=\"".$h->ManifestId."-eliminar\"  onClick=\"xajax_eliminar(this.id);return false;\">&nbsp;<img src=\"".$carpeta."/images/icono357.gif\" width=\"19\" height=\"18\"></span>
	             
				// $objResponse->addAlert("SPACES--------------------------"."-".$spaces."-");
				 //$objResponse->addAssign($h->ManifestId,"innerHTML","&nbsp;&nbsp;<span id=\"".$var."fila\"><span id=\"".$var."-mas\" onClick=\"xajax_nodoclik(this.id);return false;\"><img id=".$h->ManifestId."-mas src=\"".$carpeta."/images/mas.gif\" width=\"16\" height=\"16\"></span><span>&nbsp;<img  id=".$h->ManifestId."-carpeta align=\"absmiddle\" src=\"".$carpeta."/images/".$h->IconoActual."\" width=\"19\" height=\"17\"></span><span class=\"items\" context=\"actions\" a=\"".$this->ManifestId."\" b=\"".$this->ManifestId."\" c=\"".$this->ManifestId."\" >".htmlentities($h->Nombre, ENT_QUOTES, 'UTF-8')."</span></span>");
                 $objResponse->addAssign($h->ManifestId,"innerHTML",$spaces."<span  id=\"".$var."fila\"><span id=\"".$var."-mas\" onClick=\"xajax_nodoclik(this.id);return false;\"><img id=\"".$h->ManifestId."-expan\" src=\"".$carpeta."/images/mas.gif\" width=\"13\" height=\"13\"><img  id=\"".$h->ManifestId."-carpeta\" align=\"absmiddle\" src=\"".$carpeta."/images/".$h->IconoActual."\" width=\"19\" height=\"17\"><span class=\"items\" context=\"actions\" a=\"".$h->ManifestId."\" b=\"".$h->ManifestId."\" c=\"".$h->ManifestId."\" >&nbsp;".htmlentities($h->Nombre, ENT_QUOTES, 'UTF-8')."</span></span></span>");
				 }else{   //------------------<span id=\"".$h->ManifestId."-editar\" onClick=\"xajax_editar(this.id);return false;\">&nbsp;<img src=\"".$carpeta."/images/editar.gif\" width=\"17\" height=\"16\"></span><span id=\"".$h->ManifestId."-eliminar\"  onClick=\"xajax_eliminar(this.id);return false;\">&nbsp;<img src=\"".$carpeta."/images/icono357.gif\" width=\"19\" height=\"18\"></span>
		         
				 $objResponse->addAssign($h->ManifestId,"innerHTML", $spaces."<span id=\"".$h->ManifestId."fila\" >&nbsp;&nbsp;&nbsp;<img  align=\"absmiddle\" src=\"".$carpeta."/images/".$h->IconoActual."\" width=\"19\" height=\"17\"><span class=\"items\" context=\"actions\" a=\"".$h->ManifestId."\" b=\"".$h->ManifestId."\" c=\"".$h->ManifestId."\" >&nbsp;".htmlentities($h->Nombre, ENT_QUOTES, 'UTF-8')."</span></span>");
				 }
			     //cambio el + por menos
			     $objResponse->addAssign($this->ManifestId."-expan","src",$carpeta."/images/menos.gif");
			     // cambio el icono por el que se eligio para estado y open true
			     $this->IconoActual=$this->MatrizIconos[$this->EstadoActual]['true'];
				  //$objResponse->addAlert("Icono ".$this->IconoActual);
			     $objResponse->addAssign($this->ManifestId."-carpeta","src",$carpeta."/images/".$this->IconoActual);
                 // $objResponse->addAlert("Estado actual ".$this->EstadoActual);
			  }
				  
		 }
	   }
 
   }
  }
              //$expan="menos";
			  $objResponse->addAssign($this->ManifestId."-mas","id",$this->ManifestId."-menos");
  }// primer if de si es expan mas o no
  else{
  // en este caso expan es menos
   $objResponse->addAssign($this->ManifestId."-expan","src",$carpeta."/images/mas.gif");
			  // cambio el icono por el que se eligio para estado y open true
			  $this->IconoActual=$this->MatrizIconos[$this->EstadoActual]['false'];
				  //$objResponse->addAlert("Icono ".$this->IconoActual);
			  $objResponse->addAssign($this->ManifestId."-carpeta","src",$carpeta."/images/".$this->IconoActual);
                
 // $objResponse->addAlert("Entra menos --------------------------"." - ".$this->ManifestId.$this->Nombre."- ".$carpeta);
  $objResponse->addAssign($this->ManifestId."-menos","id",$this->ManifestId."-mas");
  // recorrere los hijos del elemento dado
  $url=$carpeta."/"."org.xml";
     if (file_exists($url))
     {
     //echo $url;
       $ObjOrg1 = simplexml_load_file($url);
        foreach ($ObjOrg1->xpath('//item') as $elemento1) {
	     // encontrado nodo del cual quiero eliminar sus hijos
         if((string)$elemento1['identifier']==$this->ManifestId){
            $this->LoadSubNodes();		   
		   // $objResponse->addAlert("contador de subnodos --------------------------"." - ".count($this->SubNodesArray));
          foreach($this->SubNodesArray as $a=>$b){
		      //$objResponse->addRemove((string)$hijos['identifier']);// asi elimino todo el div
			  
			    $objResponse->addRemove($b);
			  
			  //$objResponse->addRemove((string)$hijos['identifier']."-editar");
			  //$objResponse->addRemove((string)$hijos['identifier']."-eliminar");
			 
		   }
		    //$objResponse->addRemove((string)$this->Nombre);
			//$objResponse->loadXML($this->MuestraNodo($carpeta));
		 }
		}
	 }

  //______________
  }
   return $objResponse->getXML();
  //echo $NumAct;
}


  //***********************************************************************************
 /**
* Mostrar un nodo.
*  Esta funcin se encarga de representar el nodo contenido en las variables de clase
*  Utiliza funciones xajax para crear los elementos HTML que componen la representacin del nodo.
*  
*   
*/
 function MuestraNodo($carpeta){
   $objResponse = new xajaxResponse();
  //$objResponse->addAlert("Entra!!!!!!!!!! ".$this->Nombre." - ".$this->ManifestId);
   //$objResponse->addAlert("Icono actual ".$this->IconoActual);
   //$objResponse->addAlert("Estado actual ".$this->EstadoActual);
  $objResponse->addCreate("bod","div",$this->ManifestId);
  //analizar el nodo y segun el nodo representarlo deuna forma u otra.
  //echo $nhijos;
  if(count($this->ArrayHijos)>=1){
 	//echo $carpeta;
	//utilizo <|*|> como la combinacion de caracteres que seran el delimitador
	$var=$this->ManifestId;//."--_*_--".$carpeta."--_*_--mas--_*_--".$this->Id."--_*_--".$contnodos;
	//echo $this->IconoActual;
	//echo $var;
	     //----------<span id=".$this->ManifestId."-editar onClick=\"xajax_editar(this.id);return false;\">&nbsp;<img src=\"".$carpeta."/images/editar.gif\" width=\"17\" height=\"16\"></span><span id=\"".$this->ManifestId."-eliminar\"  onClick=\"xajax_eliminar(this.id);return false;\">&nbsp;<img src=\"".$carpeta."/images/icono357.gif\" width=\"19\" height=\"18\"></span>
         $objResponse->addAssign($this->ManifestId,"innerHTML","<span  id=\"".$var."fila\"><span id=\"".$var."-mas\" onClick=\"xajax_nodoclik(this.id);return false;\"><img id=\"".$this->ManifestId."-expan\" src=\"".$carpeta."/images/mas.gif\" width=\"13\" height=\"13\"><img  id=\"".$this->ManifestId."-carpeta\" align=\"absmiddle\" src=\"".$carpeta."/images/".$this->IconoActual."\" width=\"19\" height=\"17\"><span class=\"items\" context=\"actions\" a=\"".$this->ManifestId."\" b=\"".$this->ManifestId."\" c=\"".$this->ManifestId."\" >&nbsp;".htmlentities($this->Nombre, ENT_QUOTES, 'UTF-8')."</span></span></span>");
        }else{
		 $objResponse->addAssign($this->ManifestId,"innerHTML", "<span id=\"".$this->ManifestId."fila\" onClick=\"xajax_nodoclik(this.id);return false;\">&nbsp;&nbsp;&nbsp;<img  align=\"absmiddle\" src=\"".$carpeta."/images/".$this->IconoActual."\" width=\"19\" height=\"17\"><span class=\"items\" context=\"actions\" a=\"".$this->ManifestId."\" b=\"".$this->ManifestId."\" c=\"".$this->ManifestId."\" >&nbsp;".htmlentities($this->Nombre, ENT_QUOTES, 'UTF-8')."</span></span>");
		}
  //$objResponse->addCreate($this->ManifestId,"<span>",$this->ManifestId."-menu");
  //$objResponse->addAssign($this->ManifestId."-menu","style","display:none");
  //$objResponse->addAssign($this->ManifestId."-menu","innerHTML", "<lu><li>aaa</li><li>eee</li></lu>");
   return $objResponse->getXML();
  //echo $NumAct;
   
 }

 /**
* Muestra Raiz.
*
*  Nodo Raiz (nombre principal del curso o coleccion )
*  Esta funcion representa en el navegador el nodo raiz. 
*  Se ha realizado una funcin especial para representar a este nodo por que tiene caracteristicas diferentes al resto.
*  Este nodo siempre esta expandido.
*  Esta funcin utiliza funciones xajax para crear los elementos html que compondran la representacion del nodo raiz
*  
*/
 function MuestraRaiz($carpeta){
  $s=$carpeta."/images/".$this->IconoActual;
 // echo $s;
 // el nodo raiz no es expandible pues  siempre estara expandido
  $objResponse = new xajaxResponse();
  //$objResponse->addAlert("Entra!!!!!!!!!! ".$this->Nombre);
  $objResponse->addCreate("bod","div",$this->ManifestId);
  // editar y guardar con iconos ----------<span id=\"".$this->ManifestId."\"-editar onClick=\"xajax_editar(this.id);return false;\">&nbsp;<img src=\"".$carpeta."/images/editar.gif\" width=\"17\" height=\"16\"></span><span id=\"".$this->ManifestId."-guardar\">&nbsp;<img id=\"".$this->ManifestId."\"src=\"".$carpeta."/images/guardard.gif\" onClick=\"xajax_Guardar(this.id);return false;\" width=\"18\" height=\"19\"></span>
  $objResponse->addAssign($this->ManifestId,"innerHTML","<span ><img src=\"".$carpeta."/images/".$this->IconoActual."\" width=\"16\" height=\"16\">"."&nbsp;<span class=\"items\" context=\"actions\" a=\"".$this->ManifestId."\" b=\"".$this->ManifestId."\" c=\"".$this->ManifestId."\" ><b>".$this->Nombre."<b></span></span>");
   //////////<span context="actions" a="Homer Simpson" b="homer@simpsons.com" c="01239992021">Homer Simpson</span>  
   return $objResponse->getXML();
   
 }

 
}//class
?>